.. _CMOS architecure:

####
CMOS
####

API reference: :py:class:`~pyxel.detectors.CMOS`

Available models
================

* Photon generation
    * :ref:`Load image`
    * :ref:`Simple illumination`
    * :ref:`Stripe pattern`
    * :ref:`Shot noise`
* Optics
    * :ref:`Physical Optics Propagation in PYthon (POPPY)`
    * :ref:`Load PSF`
* Charge generation
    * :ref:`Simple photoconversion`
    * :ref:`Conversion with custom QE map`
    * :ref:`Load charge`
    * :ref:`CosmiX cosmic ray model`
    * :ref:`Dark current rule07`
    * :ref:`Dark current`
    * :ref:`Simple dark current`
* Charge collection
    * :ref:`Simple collection`
    * :ref:`Simple full well`
    * :ref:`Fixed pattern noise`
    * :ref:`Inter pixel capacitance`
    * :ref:`Simple persistence`
    * :ref:`Persistence`
* Charge measurement:
    * :ref:`DC offset`
    * :ref:`kTC reset noise`
    * :ref:`Simple charge measurement`
    * :ref:`Output node noise CMOS`
    * :ref:`Non-linearity (polynomial)`
    * :ref:`HxRG noise generator`
* Readout electronics:
    * :ref:`Simple ADC`
    * :ref:`Simple amplification`
    * :ref:`DC crosstalk`
    * :ref:`AC crosstalk`
    * :ref:`SAR ADC`